Skip to contents

This function calculates the coefficient of variation (CV) for each column in a data frame.

Usage

CV.df(df)

Arguments

df

A data frame with row samples and column features.

Value

A sorted vector of CV values for each column in the data frame, in decreasing order.

Author

Zaoqu Liu; E-mail: liuzaoqu@163.com