Skip to contents

This function calculates the median absolute deviation (MAD) for each column in a data frame.

Usage

MAD.df(df)

Arguments

df

A data frame with row samples and column features.

Value

A sorted vector of MAD values for each column in the data frame, in decreasing order.

Author

Zaoqu Liu; E-mail: liuzaoqu@163.com