Skip to contents

This function calculates the mean value for each column in a data frame.

Usage

Mean.df(df)

Arguments

df

A data frame with row samples and column features.

Value

A vector of mean values for each column in the data frame.

Author

Zaoqu Liu; E-mail: liuzaoqu@163.com