Skip to contents

This function performs clustering analysis using Similarity Network Fusion (SNF), which integrates multiple data types to provide a unified clustering result.

Usage

RunSNF(
  data,
  N.clust = NULL,
  num.neighbors = 20,
  variance = 0.5,
  num.iterations = 20
)

Arguments

data

A list of matrices where each element represents a different modality. Each matrix should have rows as features and columns as samples.

N.clust

Integer. Number of clusters for spectral clustering.

num.neighbors

Integer. Number of nearest neighbors (default: 20).

variance

Numeric. Variance for local model (default: 0.5).

num.iterations

Integer. Number of SNF iterations (default: 20).

Value

A data frame with Sample, Cluster, and Cluster2 columns.

References

Wang B, et al. Nat Methods. 2014;11(3):333-337.

Author

Zaoqu Liu; Email: liuzaoqu@163.com