R/Select.Features.R
CV.df.Rd
This function calculates the coefficient of variation (CV) for each column in a data frame.
CV.df(df)
A data frame with row samples and column features.
A sorted vector of CV values for each column in the data frame, in decreasing order.
Zaoqu Liu; E-mail: liuzaoqu@163.com