R/Select.Features.R
MAD.df.Rd
This function calculates the median absolute deviation (MAD) for each column in a data frame.
MAD.df(df)
A data frame with row samples and column features.
A sorted vector of MAD values for each column in the data frame, in decreasing order.
Zaoqu Liu; E-mail: liuzaoqu@163.com