This function selects hypervariable features from a data frame based on specified variance calculation methods.
Usage
Select.Features(
data,
method = "mad",
top.percent = NULL,
top.number = 1000,
custom.features = NULL
)Arguments
- data
A data frame with row features and column samples.
- method
Method of calculating variance ("sd", "mad", "cv").
- top.percent
The top percent of hypervariable features based on variance.
- top.number
The top number of hypervariable features based on variance.
- custom.features
A vector of custom features to select.
Examples
if (FALSE) { # \dontrun{
df <- data.frame(matrix(rnorm(1000), nrow = 100, ncol = 10))
selected_features <- Select.Features(df, method = "mad", top.percent = 10)
} # }